%{H_TEMPLATE}

#ifndef KMDIKONSOLE_H
#define KMDIKONSOLE_H

#include <tqvbox.h>

class kmdikonsole : public TQVBox
{
	Q_OBJECT
  TQ_OBJECT

	public:
		kmdikonsole( TQWidget* parent, const char* name=0);
		~kmdikonsole();

	public slots:
		void setDirectory(const TQString & dir);
		void activate();

	private slots:
		void slotDestroyed();
		void respawn();

	protected:
		void showEvent(TQShowEvent *ev);

	private:
		KParts::ReadOnlyPart *m_part;
		bool m_haskonsole;
};

#endif // KMDIKONSOLE_H
